<?php

use GuzzleHttp\Client as HttpClient;

class Hosttechdns_Api {

    public function config(){
        return include 'config.api.php';
    }

    public function getProfile () {
        return $this->call('get', 'v'.self::config()['version'].'/auth/me', [], true);
    }

    public function generateToken ($username, $password) {
        return $this->call('post', 'v'.self::config()['version'].'/auth/personal-access-tokens/credentials', [
            'username' => $username,
            'password' => $password,
            'name' => 'WHMCS'
        ]);
    }

    public function saveZone($domain, $records) {
        return $this->call('put', 'user/v'.self::config()['version'].'/zones/'.$domain, ['records' => $records], true);
    }

    public function getZone($domain) {
        return $this->call('get', 'user/v'.self::config()['version'].'/zones/'.$domain, [], true);
    }

    public function createZone($name, $email, $ttl, $nameserver, $dnssec = false){
        return $this->call('post', 'user/v'.self::config()['version'].'/zones', [
            'name' => $name,
            'email' => $email,
            'ttl' =>$ttl,
            'nameserver' => $nameserver,
            'dnssec' => (int) $dnssec
        ], true);
    }

	private function call($type, $endpoint, $data, $auth = false) {
        $headers = [
            'Accept' => 'application/json'
        ];

        if($auth){
            $headers['Authorization'] = 'Bearer ' . Hosttechdns_Core::getConfig('access_token');
        }

        $http = new HttpClient([
            'headers' => $headers,
        ]);

        $response = $http->{$type}(self::config()['url'].$endpoint,
            [
                'http_errors' => false,
                'json' => $data,
            ]);
        return json_decode($response->getBody(), 1);
    }

}
