<?php

/**
 * hosttech DNS Manager 1.1
 */

if (!defined("WHMCS")) {
    die("This file cannot be accessed directly");
}

use WHMCS\ClientArea;
use WHMCS\User\Client;
use WHMCS\Domain\Domain;

require_once __DIR__ . DIRECTORY_SEPARATOR . 'hosttech_core' . DIRECTORY_SEPARATOR . 'Core.php';
require_once __DIR__ . DIRECTORY_SEPARATOR . 'hosttech_core' . DIRECTORY_SEPARATOR . 'Api.php';

function hosttechdns_config()
{
    $configarray = array(
        "name" => "hosttech DNS Manager",
        "description" => "This module replaces the default DNS management.",
        "version" => "1.4",
        "author" => "hosttech GmbH",
        "fields" => array(
            "user" => array("FriendlyName" => "Username", "Type" => "text", "Size" => "25",
                "Description" => "Username",),
            "pass" => array("FriendlyName" => "Password", "Type" => "password", "Size" => "25",
                "Description" => "Password",),
        ));
    return $configarray;
}

function hosttechdns_ClientArea($vars)
{

    $api = new Hosttechdns_Api();

    if (empty(Hosttechdns_Core::getConfig('access_token'))) { // if no token exists yet
        if (!empty($vars['user']) && !empty($vars['pass'])) { // if username and password are set
            $user = $vars['user'];
            $pass = $vars['pass'];

            $response = $api->generateToken($user, $pass);

            Hosttechdns_Core::setConfig(['access_token' => $response['data']['token']]);
        }
    }
    $clientid = $_SESSION['uid'];

    if (isset($_REQUEST['domainid'])) {
        $domainid = $_REQUEST['domainid'];
    }

    $domain = Domain::find($domainid);


    // Only proceed if this domain belongs to the client
    if (!$domain || $domain->clientId !== $clientid) {
        die('Access denied for this domain.');
    }

    $errors = [];
    $success = false;

    $nameserversets = $api->getProfile()['data']['nameserversets'];

    if(!empty($_POST['records'])) {
        $submitted_records = $_POST['records'];
        $response = $api->saveZone($domain->domain, $submitted_records);
        if(!empty($response['errors'])){
            foreach($response['errors'] as $key => $error){
                $error_field = explode('.', $key);
                $errors[$error_field[1]][$error_field[2]] = $error;
            }
            $records = $submitted_records;
        }else{
            $success = true;
            $records = $response['data']['records'];
        }
    }else{
        $zoneData = $api->getZone($domain->domain)['data'];
        if(empty($zoneData)){
            $zoneData = $api->createZone(
                $domain->domain,
                $domain->client->email,
                10800,
                !empty($nameserversets[0]['servers'][0]) ? $nameserversets[0]['servers'][0] : Hosttechdns_Core::DEFAULT_NS
            );
        }

        $records = $zoneData['records'];
    }

    return array(
        'pagetitle' => sprintf($vars['_lang']['PageTitle'], $domain->domain),
        'templatefile' => 'dnsrecords',
        'breadcrumb' => array(
            'clientarea.php' => 'Client Area',
            'clientarea.php?action=domains' => 'My Domains',
            'clientarea.php?action=domaindetails&id=' . $domainid => $domain->domain,
            'index.php?m=hosttechdns&domainid=' . $domainid => 'DNS Records',
        ),
        'requirelogin' => true,
        'vars' => array(
            'record_types' => Hosttechdns_Core::getRecordTypes(),
            'records' => $records,
            'errors' => $errors,
            'success' => $success,
            '_lang' => $vars['_lang']
        ),
    );
}
